@@ -1,8 +1,8 @@
 /*
  * crc32.h
  */
-#ifndef _CRC32_H
-#define _CRC32_H
+#ifndef CRC32_H_INCLUDED
+#define CRC32_H_INCLUDED
 
 #include <inttypes.h>
 #include <stdlib.h>
@@ -16,4 +16,4 @@ extern uint32_t  crc32_be(uint32_t crc, unsigned char const *p, size_t len);
 #define ether_crc_le(length, data) crc32_le(~0, data, length)
 #define ether_crc(length, data)    crc32_be(~0, data, length)
 
-#endif /* _CRC32_H */
+#endif /* CRC32_H_INCLUDED */
