@@ -5,7 +5,7 @@
  */
 #include <stdio.h>
 #include <string.h>
-#include <libudev.h>
+#include "mt-udev-wrap.h"
 #include <dirent.h>
 #include <limits.h>
 #include <errno.h>
@@ -168,13 +168,19 @@ out:
 	return retval;
 }
 
+static const char *avoid_null(const char *s)
+{
+	return s ? s : "(unset)";
+}
+
 static void _log_match(const char *fn, const struct hwentry *h,
 		       const char *vendor, const char *product,
 		       const char *revision)
 {
 	condlog(4, "%s: found match /%s:%s:%s/ for '%s:%s:%s'", fn,
-		h->vendor, h->product, h->revision,
-		vendor, product, revision);
+		avoid_null(h->vendor), avoid_null(h->product),
+		avoid_null(h->revision), avoid_null(vendor),
+		avoid_null(product), avoid_null(revision));
 }
 #define log_match(h, v, p, r) _log_match(__func__, (h), (v), (p), (r))
 
@@ -203,7 +209,8 @@ find_hwe (const struct vector_s *hwtable,
 		log_match(tmp, vendor, product, revision);
 	}
 	condlog(n > 1 ? 3 : 4, "%s: found %d hwtable matches for %s:%s:%s",
-		__func__, n, vendor, product, revision);
+		__func__, n, avoid_null(vendor), avoid_null(product),
+		avoid_null(revision));
 	return n;
 }
 
@@ -470,6 +477,7 @@ merge_hwe (struct hwentry * dst, struct hwentry * src)
 	merge_num(marginal_path_err_rate_threshold);
 	merge_num(marginal_path_err_recheck_gap_time);
 	merge_num(marginal_path_double_failed_time);
+	merge_num(purge_disconnected);
 
 	snprintf(id, sizeof(id), "%s/%s", dst->vendor, dst->product);
 	reconcile_features_with_options(id, &dst->features,
@@ -517,6 +525,7 @@ merge_mpe(struct mpentry *dst, struct mpentry *src)
 	merge_num(skip_kpartx);
 	merge_num(max_sectors_kb);
 	merge_num(ghost_delay);
+	merge_num(purge_disconnected);
 	merge_num(uid);
 	merge_num(gid);
 	merge_num(mode);
