@@ -408,6 +408,13 @@ static struct hwentry default_hw[] = {
 		.prio_name     = PRIO_ALUA,
 		.pgfailback    = -FAILBACK_IMMEDIATE,
 	},
+	{
+		// EqualLogic PS Series
+		.vendor        = "EQLOGIC",
+		.product       = "100E-00",
+		.pgpolicy      = MULTIBUS,
+		.no_path_retry = 30,
+	},
 	/*
 	 * Fujitsu
 	 */
@@ -503,6 +510,12 @@ static struct hwentry default_hw[] = {
 		.checker_name  = DIRECTIO,
 		.detect_checker = DETECT_CHECKER_OFF,
 	},
+	{
+		// VSP NVMe
+		.vendor        = "NVME",
+		.product       = "HITACHI SVOS-RF-System",
+		.no_path_retry = NO_PATH_RETRY_QUEUE,
+	},
 	/*
 	 * IBM
 	 */
@@ -669,7 +682,7 @@ static struct hwentry default_hw[] = {
 		.pgfailback    = -FAILBACK_IMMEDIATE,
 	},
 	{
-		// Storwize V5000/V7000 lines / SAN Volume Controller (SVC)
+		// Storwize V3x00/V5000/V7000 lines / SAN Volume Controller (SVC)
 		// Flex System V7000 / FlashSystem V840/V9000 and 5x00/7x00/9x00/Cx00
 		.vendor        = "IBM",
 		.product       = "^2145",
@@ -1114,7 +1127,6 @@ static struct hwentry default_hw[] = {
 		/* OceanStor NVMe */
 		.vendor        = "NVME",
 		.product       = "Huawei-XSG1",
-		.checker_name  = DIRECTIO,
 		.no_path_retry = 12,
 	},
 	/*
@@ -1142,6 +1154,12 @@ static struct hwentry default_hw[] = {
 		.dev_loss      = MAX_DEV_LOSS_TMO,
 		.detect_prio   = DETECT_PRIO_OFF,
 	},
+	{
+		// InfiniBox NVMe
+		.vendor        = "NVME",
+		.product       = "InfiniBox",
+		.no_path_retry = NO_PATH_RETRY_QUEUE,
+	},
 	/*
 	 * Kaminario
 	 */
@@ -1308,6 +1326,15 @@ static struct hwentry default_hw[] = {
 		.prio_name     = PRIO_ALUA,
 		.no_path_retry = 30,
 	},
+	{
+		// Exos / Nytro series
+		.vendor        = "SEAGATE",
+		.product       = "^[456]",
+		.pgpolicy      = GROUP_BY_PRIO,
+		.pgfailback    = -FAILBACK_IMMEDIATE,
+		.prio_name     = PRIO_ALUA,
+		.no_path_retry = 30,
+	},
 	/*
 	 * AccelStor
 	 */
@@ -1371,6 +1398,42 @@ static struct hwentry default_hw[] = {
 		.pgpolicy      = GROUP_BY_SERIAL,
 		.no_path_retry = 30,
 	},
+	/*
+	 * Acronis
+	 */
+	{
+		// Cyber Infrastructure
+		.vendor        = "VSTORAGE",
+		.product       = "VSTOR-DISK",
+		.prio_name     = PRIO_ALUA,
+		.pgpolicy      = GROUP_BY_NODE_NAME,
+		.detect_prio   = DETECT_PRIO_OFF,
+		.features      = "2 pg_init_retries 50",
+		.pgfailback    = -FAILBACK_IMMEDIATE,
+		.flush_on_last_del = FLUSH_ALWAYS,
+		.no_path_retry = NO_PATH_RETRY_QUEUE,
+	},
+	/*
+	 * QSAN
+	 */
+	{
+		// XF / XCubeFAS / XCubeSAN / XN / XCubeNXT Series
+		.vendor        = "^Qsan",
+		.product       = ".*",
+		.pgpolicy      = GROUP_BY_PRIO,
+		.pgfailback    = -FAILBACK_IMMEDIATE,
+		.no_path_retry = 30,
+		.prio_args     = "exclusive_pref_bit",
+	},
+	/*
+	 * VAST Data
+	 */
+	{
+		// Block Subsystem NVMe
+		.vendor        = "NVME",
+		.product       = "VASTData",
+		.no_path_retry = NO_PATH_RETRY_QUEUE,
+	},
 	/*
 	 * EOL
 	 */
