@@ -54,4 +54,7 @@ int resize_map(struct multipath *mpp, unsigned long long size,
 	       struct vectors *vecs);
 void set_pr(struct multipath *mpp);
 void unset_pr(struct multipath *mpp);
+void pr_register_active_paths(struct multipath *mpp,
+			      const struct vector_s *registered_paths);
+void cleanup_reset_vec(struct vector_s **v);
 #endif /* MAIN_H_INCLUDED */
